]> git.tdb.fi Git - ext/subsurface.git/commitdiff
Use a 'notebook' for Info vs Profile
authorLinus Torvalds <torvalds@linux-foundation.org>
Wed, 31 Aug 2011 23:10:11 +0000 (16:10 -0700)
committerLinus Torvalds <torvalds@linux-foundation.org>
Wed, 31 Aug 2011 23:10:11 +0000 (16:10 -0700)
I dunno.  This seems a better interface at least if we get more info for
the dive, but I suspect I'll want to the add basic info to the profile
page too.

This makes the 'table' approach to layout be kind of pointless again,
and the table has become a fancy vbox.  Maybe I'll put the core info
back, and use the notebook 'Info' page for extended information.

I should just bite the bullet and start saving the dive data, and adding
editing functions for adding information.  But instead I'm playing
around with random gtk widgets.

Signed-off-by: Linus Torvalds <torvalds@linux-foundation.org>
main.c

diff --git a/main.c b/main.c
index 6a82c6f933e4e3f6cab9ef53d777e72c4a36b6aa..14bf6e70834c946c6f963e412e30e0dd5ab80ab9 100644 (file)
--- a/main.c
+++ b/main.c
@@ -61,6 +61,7 @@ int main(int argc, char **argv)
        GtkWidget *win;
        GtkWidget *divelist;
        GtkWidget *table;
+       GtkWidget *notebook;
        GtkWidget *frame;
 
        parse_xml_init();
@@ -92,14 +93,18 @@ int main(int argc, char **argv)
        divelist = create_dive_list();
        gtk_table_attach_defaults(GTK_TABLE(table), divelist, 0, 1, 0, 2);
 
-       /* Frame for dive profile */
-       frame = dive_profile_frame();
-       gtk_table_attach_defaults(GTK_TABLE(table), frame, 1, 2, 1, 2);
-       dive_profile = frame;
+       /* Notebook for dive info vs profile vs .. */
+       notebook = gtk_notebook_new();
+       gtk_table_attach_defaults(GTK_TABLE(table), notebook, 1, 2, 1, 2);
 
        /* Frame for dive info */
        frame = dive_info_frame();
-       gtk_table_attach_defaults(GTK_TABLE(table), frame, 1, 2, 0, 1);
+       gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, gtk_label_new("Dive Info"));
+
+       /* Frame for dive profile */
+       frame = dive_profile_frame();
+       gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, gtk_label_new("Dive Profile"));
+       dive_profile = frame;
 
        gtk_widget_set_app_paintable(win, TRUE);
        gtk_widget_show_all(win);